Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(447)

Unified Diff: ui/arc/notification/arc_custom_notification_view.h

Issue 2704933011: Add notification settings button to ARC notifications. (Closed)
Patch Set: Add notification settings button to ARC notifications. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/arc/notification/arc_custom_notification_view.h
diff --git a/ui/arc/notification/arc_custom_notification_view.h b/ui/arc/notification/arc_custom_notification_view.h
index 7eae0013b453de5336d4f8f8a23691b3f9586bd1..41c5347ac83324835fc99e089db0dd49cc0f7e97 100644
--- a/ui/arc/notification/arc_custom_notification_view.h
+++ b/ui/arc/notification/arc_custom_notification_view.h
@@ -43,14 +43,15 @@ class ArcCustomNotificationView
private:
class ContentViewDelegate;
- class CloseButton;
+ class ControlButton;
class EventForwarder;
+ class SettingsButton;
class SlideHelper;
- void CreateFloatingCloseButton();
+ void CreateFloatingControlButtons();
void SetSurface(exo::NotificationSurface* surface);
void UpdatePreferredSize();
- void UpdateCloseButtonVisiblity();
+ void UpdateControlButtonsVisiblity();
void UpdatePinnedState();
void UpdateSnapshot();
void AttachSurface();
@@ -101,13 +102,15 @@ class ArcCustomNotificationView
// when a slide is in progress and restore the surface when it finishes.
std::unique_ptr<SlideHelper> slide_helper_;
// A close button on top of NotificationSurface. Needed because the
// aura::Window of NotificationSurface is added after hosting widget's
// RootView thus standard notification close button is always below
// it.
- std::unique_ptr<views::Widget> floating_close_button_widget_;
+ std::unique_ptr<views::Widget> floating_control_buttons_widget_;
- views::ImageButton* floating_close_button_ = nullptr;
+ views::View* control_buttons_view_ = nullptr;
+ views::ImageButton* close_button_ = nullptr;
+ views::ImageButton* settings_button_ = nullptr;
// Protects from call loops between Layout and OnWindowBoundsChanged.
bool in_layout_ = false;
« no previous file with comments | « ui/arc/notification/arc_custom_notification_item.h ('k') | ui/arc/notification/arc_custom_notification_view.cc » ('j') | no next file with comments »
@@ -101,13 +102,15 @@ class ArcCustomNotificationView
// when a slide is in progress and restore the surface when it finishes.
std::unique_ptr<SlideHelper> slide_helper_;
- // A close button on top of NotificationSurface. Needed because the
+ // A control buttons on top of NotificationSurface. Needed because the
// aura::Window of NotificationSurface is added after hosting widget's
@@ -101,13 +102,15 @@ class ArcCustomNotificationView
// aura::Window of NotificationSurface is added after hosting widget's
- // RootView thus standard notification close button is always below
+ // RootView thus standard notification control buttons are always below
// it.

Powered by Google App Engine
This is Rietveld 408576698